(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     51110,       1242]
NotebookOptionsPosition[     47133,       1173]
NotebookOutlinePosition[     47692,       1194]
CellTagsIndexPosition[     47649,       1191]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e36715bf-8f54-4cb4-b9ab-8778b7e1cd10"],

Cell["Chapter 5, Section 5.4, Figure 5.9", "Section",ExpressionUUID->"a15dc999-7896-4815-a0e6-d5919e54b10d"],

Cell["\<\
This figure illustrates the spin-orbit resonance configuration of Mercury.  \
The planet completes 3/2 rotations for each of its orbital periods.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.865922847484338*^9, 3.865922909373179*^9}, 
   3.8659236824749517`*^9, 3.8659237578197317`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"dd56ba58-28de-4524-8ac6-0b6cf5cad79b"],

Cell["Create a graphics object to denote the Sun.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"59874768-cf5a-4d6a-a430-8fd1e040ed0a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sun", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PointSize", "[", "0.1", "]"}], ",", 
     RowBox[{"Point", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890929389820344*^9, 3.890929389826393*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"0bb29c2b-90af-4aea-9add-333ef877cbd1"],

Cell[BoxData[
 GraphicsBox[
  {PointSize[0.1], PointBox[{0, 0}]}]], "Output",
 CellChangeTimes->{3.8909293915623093`*^9, 3.890929568109962*^9},
 CellLabel->"Out[1]=",ExpressionUUID->"efef39e8-48ed-4f4c-a11f-7dd42971504d"]
}, Open  ]],

Cell[TextData[{
 "Define a function ",
 StyleBox["ksolve", "Input"],
 " to be used to solve Kepler's equation."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"af83d2df-2c57-4468-b13b-975d11aa86bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ksolve", "[", 
    RowBox[{"ma_", ",", "e_"}], "]"}], ":=", "\n", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", " ", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.890929409520829*^9, 3.890929409527854*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"dba05fc0-32ba-4eb7-923d-0aec9dda6ecf"],

Cell[TextData[{
 "Define a function ",
 StyleBox["position", "Input"],
 " to be used to calculate an object's position vector for a given mean \
anomaly, semi-major axis and eccentricity."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9cded841-4f46-4b27-87f4-4e2b84461673"],

Cell[BoxData[
 RowBox[{
  RowBox[{"position", "[", 
   RowBox[{"ma_", ",", "a_", ",", "e_"}], "]"}], ":=", "\n", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"eca", "=", 
     RowBox[{"ea", "/.", 
      RowBox[{"ksolve", "[", 
       RowBox[{"ma", ",", "e"}], "]"}]}]}], ";", "\n", 
    RowBox[{"x", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "eca", "]"}], "-", "e"}], ")"}]}], "]"}]}], ";", 
    " ", 
    RowBox[{"y", "=", 
     RowBox[{"N", "[", 
      RowBox[{"a", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"e", "^", "2"}]}], "]"}], " ", 
       RowBox[{"Sin", "[", "eca", "]"}]}], "]"}]}], ";", "\n", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.890929422433857*^9, 3.890929422440011*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"ebd8f0eb-a0aa-4db0-8535-01cf6fd8490b"],

Cell[TextData[{
 "Set the values of the semi-major axis (",
 StyleBox["a", "Input"],
 " = 1.0) and eccentricity (",
 StyleBox["e", "Input"],
 " = 0.3).  Note that the diagram is not intended to be an accurate \
representation of the orbit."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"18c91789-44e6-4dfb-8958-8362bf96fa81"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "=", "1.0"}], ";", " ", 
  RowBox[{"e", "=", "0.3"}], ";"}]], "Input",
 CellChangeTimes->{{3.890929437447967*^9, 3.890929437454217*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"4be45e07-05d9-4f39-aac9-0bf267c7f92e"],

Cell["\<\
Create a graphics objects for the points denoting the location of the object \
at equal intervals in mean anomaly (i.e. time) around the orbit.  This is \
just a check on the orbital positions.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864542521743004*^9, 3.8645425265441647`*^9}, {
  3.865922954389283*^9, 3.86592296736446*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"21d1ccac-040c-4765-b5aa-2714c9e16712"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spoints", " ", "=", " ", "\n", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Disk", "[", 
        RowBox[{"#", ",", "0.05"}], "]"}], "&"}], ",", "\n", "   ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"position", "[", 
         RowBox[{"t", ",", "a", ",", "e"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"5", 
           RowBox[{"Pi", "/", "3"}]}], ",", 
          RowBox[{"Pi", "/", "3"}]}], "}"}]}], "]"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.890929450285227*^9, 3.890929450299081*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"b6518df8-d9b6-4ce2-b6ee-93346cd488c0"],

Cell["Draw the orbit of the object.", "Text",
 CellFrame->True,
 CellChangeTimes->{3.865923845270432*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"73ec853e-d753-497c-9e3d-5b7156f4c0ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"planetorbit", " ", "=", "\n", 
  RowBox[{"ListPlot", "[", "\n", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"position", "[", 
       RowBox[{"t", ",", "a", ",", "e"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", 
        RowBox[{"2", "Pi"}], ",", 
        RowBox[{"Pi", "/", "100"}]}], "}"}]}], "]"}], ",", "\n", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"AspectRatio", "->", "Automatic"}], ",", 
    RowBox[{"Axes", "->", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.890929467280046*^9, 3.890929467286399*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"002f7d6e-53a5-435e-8cfa-9c7fbacae9af"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdl3s4VPsaxzX1SI6iOF3pTumedLIlb5GULmSnVEgKtbXL2ZpUyqWkol1h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      "]]}}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.3, 0.7}, {-0.9538431695179883, 0.9538431695179883}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8909294682927227`*^9, 3.890929569222456*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"d3b6d18b-b055-4c84-a2a9-058f2372244f"]
}, Open  ]],

Cell["\<\
Show the planet's orbit and the positions at fixed intervals.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{3.865922986218595*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"810df551-530d-4a7a-9bfc-7a3a7ff2894d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"planetorbit", ",", "sun", ",", "spoints", ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8909294796339912`*^9, 3.890929479640173*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"332078c6-8c66-4a37-a253-4ccc14daa190"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdl3s4VPsaxzX1SI6iOF3pTumedLIlb5GULmSnVEgKtbXL2ZpUyqWkol1h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       "]]}}, {{}, {}}}, 
   {PointSize[0.1], PointBox[{0, 0}]}, {DiskBox[{0.7, 0.}, 0.05], 
    DiskBox[{-0.07045585043478225, 0.9284673553196938}, 0.05], 
    DiskBox[{-0.977437194113205, 0.7016991889044375}, 0.05], 
    DiskBox[{-1.3, 1.1682385895964448*^-16}, 0.05], 
    DiskBox[{-0.9774371941132052, -0.7016991889044373}, 0.05], 
    DiskBox[{-0.07045585043478186, -0.9284673553196937}, 0.05]}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8909294801935167`*^9, 3.89092956960872*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"fc3093b3-71a0-4b94-b0bc-14504ce9f121"]
}, Open  ]],

Cell[TextData[{
 "Store the planet\[CloseCurlyQuote]s positions, ",
 StyleBox["spudpoints",
  FontWeight->"Bold"],
 ", for future use."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.865922986218595*^9, 3.8659230566281233`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"bd1d6188-f149-4a1e-9154-6c8b600deb21"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spudpoints", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"position", "[", 
     RowBox[{"t", ",", "a", ",", "e"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"5", 
       RowBox[{"Pi", "/", "3"}]}], ",", 
      RowBox[{"Pi", "/", "3"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[8]:=",ExpressionUUID->"49b5e972-6ce1-498b-bc01-d3e054ffd97f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.7`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.07045585043478225`"}], ",", "0.9284673553196938`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.977437194113205`"}], ",", "0.7016991889044375`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.3`"}], ",", "1.1682385895964448`*^-16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9774371941132052`"}], ",", 
     RowBox[{"-", "0.7016991889044373`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.07045585043478186`"}], ",", 
     RowBox[{"-", "0.9284673553196937`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.890929492997486*^9, 3.890929569674996*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"88de32ec-798c-405b-8c8f-cc529121a9d7"]
}, Open  ]],

Cell[TextData[{
 "Store the planet\[CloseCurlyQuote]s rotation angles, ",
 StyleBox["spudangle",
  FontWeight->"Bold"],
 ", for each of the positions."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.865922986218595*^9, 3.8659230566281233`*^9}, {
  3.865923106878121*^9, 3.865923146117231*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"70545ebb-f8df-4527-bcc8-0b7ff4a6f6d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spudangle", "=", 
  RowBox[{"Table", "[", 
   RowBox[{"\[Theta]", ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", "0", ",", 
      RowBox[{"5", 
       RowBox[{"Pi", "/", "2"}]}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"0a243926-4bdf-4f99-8f42-d45fc5d1dbc0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["\[Pi]", "2"], ",", "\[Pi]", ",", 
   FractionBox[
    RowBox[{"3", " ", "\[Pi]"}], "2"], ",", 
   RowBox[{"2", " ", "\[Pi]"}], ",", 
   FractionBox[
    RowBox[{"5", " ", "\[Pi]"}], "2"]}], "}"}]], "Output",
 CellChangeTimes->{3.8909295049406567`*^9, 3.890929569692765*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"02328aed-c8b6-483e-9ab3-aa97338734aa"]
}, Open  ]],

Cell[TextData[{
 "Use the built-in ",
 StyleBox["Disk",
  FontWeight->"Bold"],
 " and ",
 StyleBox["DiskSegment",
  FontWeight->"Bold"],
 " commands to create the (exaggerated) elliptical shape, ",
 StyleBox["ell",
  FontWeight->"Bold"],
 ", of the planet with a blue portion which helps to show the orientation."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.865922986218595*^9, 3.8659230566281233`*^9}, {
  3.865923106878121*^9, 3.865923273542552*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"db4d11e4-9755-4860-be96-b62ff711ff41"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ell", "=", 
  RowBox[{"Rotate", "[", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"EdgeForm", "[", 
          RowBox[{"Thickness", "[", "Medium", "]"}], "]"}], ",", "White", ",", 
         RowBox[{"Disk", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.2", ",", "0.1"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
      
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", 
         RowBox[{"DiskSegment", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.2", ",", "0.1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "Pi"}], "/", "4"}], ",", 
             RowBox[{"Pi", "/", "4"}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
      
      RowBox[{"Graphics", "[", 
       RowBox[{"Point", "[", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], "]"}], "]"}], ",", 
      RowBox[{"PlotRange", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.22"}], ",", "0.22"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.12"}], ",", "0.12"}], "}"}]}], "}"}]}]}], "]"}], 
    ",", "Pi"}], "]"}]}]], "Input",
 CellLabel->"In[10]:=",ExpressionUUID->"91284960-94ea-42c7-8c7e-b4cd34c075c7"],

Cell[BoxData[
 RotationBox[
  GraphicsBox[{
    {GrayLevel[1], EdgeForm[Thickness[Medium]], 
     DiskBox[{0, 0}, {0.2, 0.1}]}, 
    {RGBColor[0, 0, 1], 
     InterpretationBox[
      FilledCurveBox[
       BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
        0.282842712474619, 0.}, {0.1414213562373095, 0.07071067811865475}, {
        0.1414213562373095, 0.07071067811865475}, {0.1414213562373095, 
        0.07071067811865475}, {0.1414213562373095, 0.}, {
        0.1414213562373095, -0.07071067811865475}}, 
        SplineKnots -> {
         0, 0, 0, Rational[1, 3], Rational[1, 3], Rational[2, 3], Rational[
          2, 3], 1, 1, 1}, SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, 
        SplineDegree -> 2]],
      DiskSegment[{0, 0}, {0.2, 0.1}, {
       Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, PointBox[{0, 0}]},
   PlotRange->{{-0.22, 0.22}, {-0.12, 0.12}}],
  BoxRotation->3.141592653589793]], "Output",
 CellChangeTimes->{3.8909295192082577`*^9, 3.890929569745104*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"982c8748-822f-4b3b-998e-a2a02518f761"]
}, Open  ]],

Cell[TextData[{
 "Create a list, ",
 StyleBox["spuds",
  FontWeight->"Bold"],
 ", of all the orientations to be used in the figure."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.865922986218595*^9, 3.8659230566281233`*^9}, {
  3.865923106878121*^9, 3.865923273542552*^9}, {3.865923314235561*^9, 
  3.865923345750605*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3a34aba2-c04c-4c2d-bc70-b4fc35a07d7a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spuds", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Rotate", "[", 
     RowBox[{"ell", ",", 
      RowBox[{"spudangle", "[", 
       RowBox[{"[", "ii", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ii", ",", "1", ",", "6"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[11]:=",ExpressionUUID->"1a097c34-ea87-4073-b577-1ea1813bd6b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RotationBox[
    RotationBox[
     GraphicsBox[{
       {GrayLevel[1], EdgeForm[Thickness[Medium]], 
        DiskBox[{0, 0}, {0.2, 0.1}]}, 
       {RGBColor[0, 0, 1], 
        InterpretationBox[
         FilledCurveBox[
          BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
           0.282842712474619, 0.}, {0.1414213562373095, 
           0.07071067811865475}, {0.1414213562373095, 0.07071067811865475}, {
           0.1414213562373095, 0.07071067811865475}, {0.1414213562373095, 
           0.}, {0.1414213562373095, -0.07071067811865475}}, 
           SplineKnots -> {
            0, 0, 0, Rational[1, 3], Rational[1, 3], Rational[2, 3], Rational[
             2, 3], 1, 1, 1}, SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, 
           SplineDegree -> 2]],
         DiskSegment[{0, 0}, {0.2, 0.1}, {
          Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, PointBox[{0, 0}]},
      PlotRange->{{-0.22, 0.22}, {-0.12, 0.12}}],
     BoxRotation->3.141592653589793],
    BoxRotation->0.], ",", 
   RotationBox[
    RotationBox[
     GraphicsBox[{
       {GrayLevel[1], EdgeForm[Thickness[Medium]], 
        DiskBox[{0, 0}, {0.2, 0.1}]}, 
       {RGBColor[0, 0, 1], 
        InterpretationBox[
         FilledCurveBox[
          BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
           0.282842712474619, 0.}, {0.1414213562373095, 
           0.07071067811865475}, {0.1414213562373095, 0.07071067811865475}, {
           0.1414213562373095, 0.07071067811865475}, {0.1414213562373095, 
           0.}, {0.1414213562373095, -0.07071067811865475}}, 
           SplineKnots -> {
            0, 0, 0, Rational[1, 3], Rational[1, 3], Rational[2, 3], Rational[
             2, 3], 1, 1, 1}, SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, 
           SplineDegree -> 2]],
         DiskSegment[{0, 0}, {0.2, 0.1}, {
          Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, PointBox[{0, 0}]},
      PlotRange->{{-0.22, 0.22}, {-0.12, 0.12}}],
     BoxRotation->3.141592653589793],
    BoxRotation->1.5707963267948966`], ",", 
   RotationBox[
    RotationBox[
     GraphicsBox[{
       {GrayLevel[1], EdgeForm[Thickness[Medium]], 
        DiskBox[{0, 0}, {0.2, 0.1}]}, 
       {RGBColor[0, 0, 1], 
        InterpretationBox[
         FilledCurveBox[
          BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
           0.282842712474619, 0.}, {0.1414213562373095, 
           0.07071067811865475}, {0.1414213562373095, 0.07071067811865475}, {
           0.1414213562373095, 0.07071067811865475}, {0.1414213562373095, 
           0.}, {0.1414213562373095, -0.07071067811865475}}, 
           SplineKnots -> {
            0, 0, 0, Rational[1, 3], Rational[1, 3], Rational[2, 3], Rational[
             2, 3], 1, 1, 1}, SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, 
           SplineDegree -> 2]],
         DiskSegment[{0, 0}, {0.2, 0.1}, {
          Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, PointBox[{0, 0}]},
      PlotRange->{{-0.22, 0.22}, {-0.12, 0.12}}],
     BoxRotation->3.141592653589793],
    BoxRotation->3.141592653589793], ",", 
   RotationBox[
    RotationBox[
     GraphicsBox[{
       {GrayLevel[1], EdgeForm[Thickness[Medium]], 
        DiskBox[{0, 0}, {0.2, 0.1}]}, 
       {RGBColor[0, 0, 1], 
        InterpretationBox[
         FilledCurveBox[
          BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
           0.282842712474619, 0.}, {0.1414213562373095, 
           0.07071067811865475}, {0.1414213562373095, 0.07071067811865475}, {
           0.1414213562373095, 0.07071067811865475}, {0.1414213562373095, 
           0.}, {0.1414213562373095, -0.07071067811865475}}, 
           SplineKnots -> {
            0, 0, 0, Rational[1, 3], Rational[1, 3], Rational[2, 3], Rational[
             2, 3], 1, 1, 1}, SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, 
           SplineDegree -> 2]],
         DiskSegment[{0, 0}, {0.2, 0.1}, {
          Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, PointBox[{0, 0}]},
      PlotRange->{{-0.22, 0.22}, {-0.12, 0.12}}],
     BoxRotation->3.141592653589793],
    BoxRotation->4.71238898038469], ",", 
   RotationBox[
    RotationBox[
     GraphicsBox[{
       {GrayLevel[1], EdgeForm[Thickness[Medium]], 
        DiskBox[{0, 0}, {0.2, 0.1}]}, 
       {RGBColor[0, 0, 1], 
        InterpretationBox[
         FilledCurveBox[
          BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
           0.282842712474619, 0.}, {0.1414213562373095, 
           0.07071067811865475}, {0.1414213562373095, 0.07071067811865475}, {
           0.1414213562373095, 0.07071067811865475}, {0.1414213562373095, 
           0.}, {0.1414213562373095, -0.07071067811865475}}, 
           SplineKnots -> {
            0, 0, 0, Rational[1, 3], Rational[1, 3], Rational[2, 3], Rational[
             2, 3], 1, 1, 1}, SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, 
           SplineDegree -> 2]],
         DiskSegment[{0, 0}, {0.2, 0.1}, {
          Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, PointBox[{0, 0}]},
      PlotRange->{{-0.22, 0.22}, {-0.12, 0.12}}],
     BoxRotation->3.141592653589793],
    BoxRotation->6.283185307179586], ",", 
   RotationBox[
    RotationBox[
     GraphicsBox[{
       {GrayLevel[1], EdgeForm[Thickness[Medium]], 
        DiskBox[{0, 0}, {0.2, 0.1}]}, 
       {RGBColor[0, 0, 1], 
        InterpretationBox[
         FilledCurveBox[
          BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
           0.282842712474619, 0.}, {0.1414213562373095, 
           0.07071067811865475}, {0.1414213562373095, 0.07071067811865475}, {
           0.1414213562373095, 0.07071067811865475}, {0.1414213562373095, 
           0.}, {0.1414213562373095, -0.07071067811865475}}, 
           SplineKnots -> {
            0, 0, 0, Rational[1, 3], Rational[1, 3], Rational[2, 3], Rational[
             2, 3], 1, 1, 1}, SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, 
           SplineDegree -> 2]],
         DiskSegment[{0, 0}, {0.2, 0.1}, {
          Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, PointBox[{0, 0}]},
      PlotRange->{{-0.22, 0.22}, {-0.12, 0.12}}],
     BoxRotation->3.141592653589793],
    BoxRotation->7.853981633974483]}], "}"}]], "Output",
 CellChangeTimes->{3.8909295316207027`*^9, 3.890929569800825*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"a113ce33-a971-44a4-97db-845e588cfb97"]
}, Open  ]],

Cell["\<\
Finally combine the large point denoting the Sun, the orbital ellipse, and \
the six orientations.  This is Fig.5.9.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.865922986218595*^9, 3.8659230566281233`*^9}, {
   3.865923106878121*^9, 3.865923273542552*^9}, {3.865923314235561*^9, 
   3.865923432618424*^9}, 3.8659306059001827`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6cc3fcd9-d574-47a7-9f1a-f6ca66dae525"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"sun", ",", "planetorbit", ",", 
   RowBox[{"Epilog", "->", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"spuds", "[", 
         RowBox[{"[", "ii", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"spudpoints", "[", 
          RowBox[{"[", "ii", "]"}], "]"}], "+", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", "0.6"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ii", ",", "1", ",", "6"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellLabel->"In[12]:=",ExpressionUUID->"71dbfcca-0938-43cc-8bb8-25e635dd9794"],

Cell[BoxData[
 GraphicsBox[{
   {PointSize[0.1], PointBox[{0, 0}]}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdl3s4VPsaxzX1SI6iOF3pTumedLIlb5GULmSnVEgKtbXL2ZpUyqWkol1h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       "]]}}, {{}, {}}}},
  Epilog->{
    InsetBox[
     BoxData[
      FormBox[
       RotationBox[
        RotationBox[
         GraphicsBox[{{
            EdgeForm[
             Thickness[Medium]], 
            GrayLevel[1], 
            DiskBox[{0, 0}, {0.2, 0.1}]}, {
            RGBColor[0, 0, 1], 
            InterpretationBox[
             FilledCurveBox[
              
              BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
               0.282842712474619, 0.}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 0.}, {
               0.1414213562373095, -0.07071067811865475}}, 
               SplineKnots -> {0, 0, 0, 
                 Rational[1, 3], 
                 Rational[1, 3], 
                 Rational[2, 3], 
                 Rational[2, 3], 1, 1, 1}, 
               SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, SplineDegree -> 2]], 
             
             DiskSegment[{0, 0}, {0.2, 0.1}, {
              Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, 
           PointBox[{0, 0}]}, {PlotRange -> {{-0.22, 0.22}, {-0.12, 0.12}}}], 
         BoxRotation -> 3.141592653589793], BoxRotation -> 0.], 
       TraditionalForm]], {0.7, 0.}, {0, 0}, 0.6], 
    InsetBox[
     BoxData[
      FormBox[
       RotationBox[
        RotationBox[
         GraphicsBox[{{
            EdgeForm[
             Thickness[Medium]], 
            GrayLevel[1], 
            DiskBox[{0, 0}, {0.2, 0.1}]}, {
            RGBColor[0, 0, 1], 
            InterpretationBox[
             FilledCurveBox[
              
              BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
               0.282842712474619, 0.}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 0.}, {
               0.1414213562373095, -0.07071067811865475}}, 
               SplineKnots -> {0, 0, 0, 
                 Rational[1, 3], 
                 Rational[1, 3], 
                 Rational[2, 3], 
                 Rational[2, 3], 1, 1, 1}, 
               SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, SplineDegree -> 2]], 
             
             DiskSegment[{0, 0}, {0.2, 0.1}, {
              Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, 
           PointBox[{0, 0}]}, {PlotRange -> {{-0.22, 0.22}, {-0.12, 0.12}}}], 
         BoxRotation -> 3.141592653589793], BoxRotation -> 
        1.5707963267948966`], TraditionalForm]], {-0.07045585043478225, 
     0.9284673553196938}, {0, 0}, 0.6], 
    InsetBox[
     BoxData[
      FormBox[
       RotationBox[
        RotationBox[
         GraphicsBox[{{
            EdgeForm[
             Thickness[Medium]], 
            GrayLevel[1], 
            DiskBox[{0, 0}, {0.2, 0.1}]}, {
            RGBColor[0, 0, 1], 
            InterpretationBox[
             FilledCurveBox[
              
              BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
               0.282842712474619, 0.}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 0.}, {
               0.1414213562373095, -0.07071067811865475}}, 
               SplineKnots -> {0, 0, 0, 
                 Rational[1, 3], 
                 Rational[1, 3], 
                 Rational[2, 3], 
                 Rational[2, 3], 1, 1, 1}, 
               SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, SplineDegree -> 2]], 
             
             DiskSegment[{0, 0}, {0.2, 0.1}, {
              Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, 
           PointBox[{0, 0}]}, {PlotRange -> {{-0.22, 0.22}, {-0.12, 0.12}}}], 
         BoxRotation -> 3.141592653589793], BoxRotation -> 3.141592653589793],
        TraditionalForm]], {-0.977437194113205, 0.7016991889044375}, {0, 0}, 
     0.6], 
    InsetBox[
     BoxData[
      FormBox[
       RotationBox[
        RotationBox[
         GraphicsBox[{{
            EdgeForm[
             Thickness[Medium]], 
            GrayLevel[1], 
            DiskBox[{0, 0}, {0.2, 0.1}]}, {
            RGBColor[0, 0, 1], 
            InterpretationBox[
             FilledCurveBox[
              
              BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
               0.282842712474619, 0.}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 0.}, {
               0.1414213562373095, -0.07071067811865475}}, 
               SplineKnots -> {0, 0, 0, 
                 Rational[1, 3], 
                 Rational[1, 3], 
                 Rational[2, 3], 
                 Rational[2, 3], 1, 1, 1}, 
               SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, SplineDegree -> 2]], 
             
             DiskSegment[{0, 0}, {0.2, 0.1}, {
              Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, 
           PointBox[{0, 0}]}, {PlotRange -> {{-0.22, 0.22}, {-0.12, 0.12}}}], 
         BoxRotation -> 3.141592653589793], BoxRotation -> 4.71238898038469], 
       TraditionalForm]], {-1.3, 1.1682385895964448`*^-16}, {0, 0}, 0.6], 
    InsetBox[
     BoxData[
      FormBox[
       RotationBox[
        RotationBox[
         GraphicsBox[{{
            EdgeForm[
             Thickness[Medium]], 
            GrayLevel[1], 
            DiskBox[{0, 0}, {0.2, 0.1}]}, {
            RGBColor[0, 0, 1], 
            InterpretationBox[
             FilledCurveBox[
              
              BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
               0.282842712474619, 0.}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 0.}, {
               0.1414213562373095, -0.07071067811865475}}, 
               SplineKnots -> {0, 0, 0, 
                 Rational[1, 3], 
                 Rational[1, 3], 
                 Rational[2, 3], 
                 Rational[2, 3], 1, 1, 1}, 
               SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, SplineDegree -> 2]], 
             
             DiskSegment[{0, 0}, {0.2, 0.1}, {
              Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, 
           PointBox[{0, 0}]}, {PlotRange -> {{-0.22, 0.22}, {-0.12, 0.12}}}], 
         BoxRotation -> 3.141592653589793], BoxRotation -> 6.283185307179586],
        TraditionalForm]], {-0.9774371941132052, -0.7016991889044373}, {0, 0},
      0.6], 
    InsetBox[
     BoxData[
      FormBox[
       RotationBox[
        RotationBox[
         GraphicsBox[{{
            EdgeForm[
             Thickness[Medium]], 
            GrayLevel[1], 
            DiskBox[{0, 0}, {0.2, 0.1}]}, {
            RGBColor[0, 0, 1], 
            InterpretationBox[
             FilledCurveBox[
              
              BSplineCurve[{{0.1414213562373095, -0.07071067811865475}, {
               0.282842712474619, 0.}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 
               0.07071067811865475}, {0.1414213562373095, 0.}, {
               0.1414213562373095, -0.07071067811865475}}, 
               SplineKnots -> {0, 0, 0, 
                 Rational[1, 3], 
                 Rational[1, 3], 
                 Rational[2, 3], 
                 Rational[2, 3], 1, 1, 1}, 
               SplineWeights -> {1, 1, 2, 2, 2., 2., 2.}, SplineDegree -> 2]], 
             
             DiskSegment[{0, 0}, {0.2, 0.1}, {
              Rational[-1, 4] Pi, Rational[1, 4] Pi}]]}, 
           PointBox[{0, 0}]}, {PlotRange -> {{-0.22, 0.22}, {-0.12, 0.12}}}], 
         BoxRotation -> 3.141592653589793], BoxRotation -> 7.853981633974483],
        TraditionalForm]], {-0.07045585043478186, -0.9284673553196937}, {0, 
     0}, 0.6]},
  PlotRange->{{-1.5, 1.5}, {-1.5, 1.5}}]], "Output",
 CellChangeTimes->{{3.890929546938452*^9, 3.890929569865843*^9}},
 CellLabel->"Out[12]=",ExpressionUUID->"396fd075-9138-47bd-9ce6-adfcda5c0dc5"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{990, 653},
WindowMargins->{{85, Automatic}, {Automatic, 31}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"f608bc46-e1a0-40ae-b175-ac9c0022a2c1"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"e36715bf-8f54-4cb4-b9ab-8778b7e1cd10"],
Cell[948, 30, 108, 0, 67, "Section",ExpressionUUID->"a15dc999-7896-4815-a0e6-d5919e54b10d"],
Cell[1059, 32, 397, 8, 49, "Text",ExpressionUUID->"dd56ba58-28de-4524-8ac6-0b6cf5cad79b"],
Cell[1459, 42, 169, 3, 53, "Text",ExpressionUUID->"59874768-cf5a-4d6a-a430-8fd1e040ed0a"],
Cell[CellGroupData[{
Cell[1653, 49, 410, 10, 30, "Input",ExpressionUUID->"0bb29c2b-90af-4aea-9add-333ef877cbd1"],
Cell[2066, 61, 221, 4, 377, "Output",ExpressionUUID->"efef39e8-48ed-4f4c-a11f-7dd42971504d"]
}, Open  ]],
Cell[2302, 68, 233, 7, 53, "Text",ExpressionUUID->"af83d2df-2c57-4468-b13b-975d11aa86bd"],
Cell[2538, 77, 542, 14, 52, "Input",ExpressionUUID->"dba05fc0-32ba-4eb7-923d-0aec9dda6ecf"],
Cell[3083, 93, 310, 8, 53, "Text",ExpressionUUID->"9cded841-4f46-4b27-87f4-4e2b84461673"],
Cell[3396, 103, 933, 27, 94, "Input",ExpressionUUID->"ebd8f0eb-a0aa-4db0-8535-01cf6fd8490b"],
Cell[4332, 132, 362, 10, 76, "Text",ExpressionUUID->"18c91789-44e6-4dfb-8958-8362bf96fa81"],
Cell[4697, 144, 253, 5, 30, "Input",ExpressionUUID->"4be45e07-05d9-4f39-aac9-0bf267c7f92e"],
Cell[4953, 151, 443, 9, 76, "Text",ExpressionUUID->"21d1ccac-040c-4765-b5aa-2714c9e16712"],
Cell[5399, 162, 748, 20, 73, "Input",ExpressionUUID->"b6518df8-d9b6-4ce2-b6ee-93346cd488c0"],
Cell[6150, 184, 197, 4, 53, "Text",ExpressionUUID->"73ec853e-d753-497c-9e3d-5b7156f4c0ae"],
Cell[CellGroupData[{
Cell[6372, 192, 684, 16, 94, "Input",ExpressionUUID->"002f7d6e-53a5-435e-8cfa-9c7fbacae9af"],
Cell[7059, 210, 6409, 140, 383, "Output",ExpressionUUID->"d3b6d18b-b055-4c84-a2a9-058f2372244f"]
}, Open  ]],
Cell[13483, 353, 237, 6, 53, "Text",ExpressionUUID->"810df551-530d-4a7a-9bfc-7a3a7ff2894d"],
Cell[CellGroupData[{
Cell[13745, 363, 299, 5, 30, "Input",ExpressionUUID->"332078c6-8c66-4a37-a253-4ccc14daa190"],
Cell[14047, 370, 6736, 146, 375, "Output",ExpressionUUID->"fc3093b3-71a0-4b94-b0bc-14504ce9f121"]
}, Open  ]],
Cell[20798, 519, 325, 9, 53, "Text",ExpressionUUID->"bd1d6188-f149-4a1e-9154-6c8b600deb21"],
Cell[CellGroupData[{
Cell[21148, 532, 415, 11, 30, "Input",ExpressionUUID->"49b5e972-6ce1-498b-bc01-d3e054ffd97f"],
Cell[21566, 545, 881, 25, 60, "Output",ExpressionUUID->"88de32ec-798c-405b-8c8f-cc529121a9d7"]
}, Open  ]],
Cell[22462, 573, 390, 10, 53, "Text",ExpressionUUID->"70545ebb-f8df-4527-bcc8-0b7ff4a6f6d3"],
Cell[CellGroupData[{
Cell[22877, 587, 355, 9, 30, "Input",ExpressionUUID->"0a243926-4bdf-4f99-8f42-d45fc5d1dbc0"],
Cell[23235, 598, 417, 10, 49, "Output",ExpressionUUID->"02328aed-c8b6-483e-9ab3-aa97338734aa"]
}, Open  ]],
Cell[23667, 611, 552, 16, 76, "Text",ExpressionUUID->"db4d11e4-9755-4860-be96-b62ff711ff41"],
Cell[CellGroupData[{
Cell[24244, 631, 1590, 47, 73, "Input",ExpressionUUID->"91284960-94ea-42c7-8c7e-b4cd34c075c7"],
Cell[25837, 680, 1074, 22, 215, "Output",ExpressionUUID->"982c8748-822f-4b3b-998e-a2a02518f761"]
}, Open  ]],
Cell[26926, 705, 420, 11, 53, "Text",ExpressionUUID->"3a34aba2-c04c-4c2d-bc70-b4fc35a07d7a"],
Cell[CellGroupData[{
Cell[27371, 720, 382, 10, 30, "Input",ExpressionUUID->"1a097c34-ea87-4073-b577-1ea1813bd6b2"],
Cell[27756, 732, 6328, 136, 412, "Output",ExpressionUUID->"a113ce33-a971-44a4-97db-845e588cfb97"]
}, Open  ]],
Cell[34099, 871, 442, 9, 53, "Text",ExpressionUUID->"6cc3fcd9-d574-47a7-9f1a-f6ca66dae525"],
Cell[CellGroupData[{
Cell[34566, 884, 980, 29, 52, "Input",ExpressionUUID->"71dbfcca-0938-43cc-8bb8-25e635dd9794"],
Cell[35549, 915, 11568, 255, 400, "Output",ExpressionUUID->"396fd075-9138-47bd-9ce6-adfcda5c0dc5"]
}, Open  ]]
}
]
*)

